'use strict';
// ********************************
// NOTE: expects plotly.js to be
// included via script tag in HTML
// ********************************

const processXRD = rawData => {
    const sep = rawData.includes('\r') ? '\r': '\n';
    const axes = rawData.split(sep)
        .map(r => r.replace('\n', '')
        .split(/[\s,]+/));

    let x = [], y = [];

    for (const value of axes) {
        x.push(value[0]);
        y.push(value[1]);
    }

    return [x, y];
};

const processXRF = rawData => {
    // Do stuff...
};

const techniques = {
    'XRD' : {
        process : processXRD,
        plot_type : 'XRD Diffractometer',
        x_title : '2Theta (°)',
        y_title : 'Intensity (Counts)',
    },
    'XRF' : processXRF,
};
/**
 * @param {string} rawData
 * @param {string} technique XRD, XRF
 * @param {string} containerId
 *
 * @returns {void}
 */
export function plot(rawData, technique, containerId)
{
    let container = document.querySelector(`#${containerId}`);
    const spectrumType = techniques[technique];
    const processed = spectrumType.process(rawData);

    Plotly.newPlot(
        container, 
        [{
            x: processed[0],
            y: processed[1],
        }],
        {
            hovermode:'closest',
            title: 'Hover with mouse on data points to see annotations',
            xaxis: { zeroline : false, title : spectrumType.x_title },
            yaxis: { zeroline : false, title : spectrumType.y_title }
        },
        {
            margin: {t: 0}
        }
    );
}
